shifty Python bindings
======================

The ``shifty`` extension exposes the Rust SHACL validation engine to Python via
PyO3, targeting RDFLib-centric workflows.

.. toctree::
   :maxdepth: 2
   :caption: Contents

   installation
   usage
   api
